==> kubernetes-model-networking-5.3.0-sources.jar: io/fabric8/kubernetes/api/model/networking/v1beta1/IngressBackendBuilder.java <==
package io.fabric8.kubernetes.api.model.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class IngressBackendBuilder extends io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackendFluentImpl<io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackendBuilder> implements VisitableBuilder<io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackend,io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackendBuilder> {

    io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackendFluent<?> fluent;
    Boolean validationEnabled;

    public IngressBackendBuilder() {
        this(true);
    }

    public IngressBackendBuilder(Boolean validationEnabled) {
        this(new IngressBackend(), validationEnabled);
    }

    public IngressBackendBuilder(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackendFluent<?> fluent) {
        this(fluent, true);
    }

    public IngressBackendBuilder(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackendFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new IngressBackend(), validationEnabled);
    }

    public IngressBackendBuilder(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackendFluent<?> fluent,io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackend instance) {
        this(fluent, instance, true);
    }

    public IngressBackendBuilder(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackendFluent<?> fluent,io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackend instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withResource(instance.getResource()); 
        fluent.withServiceName(instance.getServiceName()); 
        fluent.withServicePort(instance.getServicePort()); 
        this.validationEnabled = validationEnabled; 
    }

    public IngressBackendBuilder(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackend instance) {
        this(instance,true);
    }

    public IngressBackendBuilder(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackend instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withResource(instance.getResource()); 
        this.withServiceName(instance.getServiceName()); 
        this.withServicePort(instance.getServicePort()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackend build() {
        IngressBackend buildable = new IngressBackend(fluent.getResource(),fluent.getServiceName(),fluent.getServicePort());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        IngressBackendBuilder that = (IngressBackendBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> kubernetes-model-networking-5.3.1-sources.jar: io/fabric8/kubernetes/api/model/networking/v1beta1/IngressBackendBuilder.java <==
package io.fabric8.kubernetes.api.model.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class IngressBackendBuilder extends io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackendFluentImpl<io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackendBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackend,io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackendBuilder> {

    io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackendFluent<?> fluent;
    Boolean validationEnabled;

    public IngressBackendBuilder() {
        this(true);
    }

    public IngressBackendBuilder(Boolean validationEnabled) {
        this(new IngressBackend(), validationEnabled);
    }

    public IngressBackendBuilder(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackendFluent<?> fluent) {
        this(fluent, true);
    }

    public IngressBackendBuilder(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackendFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new IngressBackend(), validationEnabled);
    }

    public IngressBackendBuilder(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackendFluent<?> fluent,io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackend instance) {
        this(fluent, instance, true);
    }

    public IngressBackendBuilder(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackendFluent<?> fluent,io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackend instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withResource(instance.getResource()); 
        fluent.withServiceName(instance.getServiceName()); 
        fluent.withServicePort(instance.getServicePort()); 
        this.validationEnabled = validationEnabled; 
    }

    public IngressBackendBuilder(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackend instance) {
        this(instance,true);
    }

    public IngressBackendBuilder(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackend instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withResource(instance.getResource()); 
        this.withServiceName(instance.getServiceName()); 
        this.withServicePort(instance.getServicePort()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackend build() {
        IngressBackend buildable = new IngressBackend(fluent.getResource(),fluent.getServiceName(),fluent.getServicePort());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        IngressBackendBuilder that = (IngressBackendBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
